@@ -26,10 +26,10 @@ CVS Information:
 
   $Source: /home/globdev/CVS/globus-1998_04_16/Globus/Miscellaneous/common/libra
 ry/globus_strptime.c,v $
-  $Date: 2006/01/19 05:54:14 $
-  $Revision: 1.7 $
-  $State: Exp $
-  $Author: mlink $
+  $Date$
+  $Revision$
+  $State$
+  $Author$
 ******************************************************************************/
 
 /******************************************************************************
